@@ -12,10 +12,10 @@ class NSEC3PARAMRecordTest {
   @Test
   void rdataFromString() throws IOException {
     Tokenizer t = new Tokenizer("1 1 10 5053851B");
-    NSEC3PARAMRecord record = new NSEC3PARAMRecord();
-    record.rdataFromString(t, null);
-    assertEquals(NSEC3Record.Digest.SHA1, record.getHashAlgorithm());
-    assertEquals(NSEC3Record.Flags.OPT_OUT, record.getFlags());
-    assertNotNull(record.getSalt());
+    NSEC3PARAMRecord nsec3PARAMRecord = new NSEC3PARAMRecord();
+    nsec3PARAMRecord.rdataFromString(t, null);
+    assertEquals(NSEC3Record.Digest.SHA1, nsec3PARAMRecord.getHashAlgorithm());
+    assertEquals(NSEC3Record.Flags.OPT_OUT, nsec3PARAMRecord.getFlags());
+    assertNotNull(nsec3PARAMRecord.getSalt());
   }
 }
