@@ -15,16 +15,16 @@ class NSEC3RecordTest {
     Tokenizer t =
         new Tokenizer(
             "1 1 10 5053851B PF2TNEL79K4HTCBINCDBE9FPBU5I04KD A NS SOA MX AAAA RRSIG DNSKEY NSEC3PARAM TYPE65534");
-    NSEC3Record record = new NSEC3Record();
-    record.rdataFromString(t, null);
-    assertEquals(NSEC3Record.Digest.SHA1, record.getHashAlgorithm());
-    assertEquals(NSEC3Record.Flags.OPT_OUT, record.getFlags());
-    assertNotNull(record.getSalt());
-    record = new NSEC3Record();
-    record.rdataFromString(
+    NSEC3Record nsec3Record = new NSEC3Record();
+    nsec3Record.rdataFromString(t, null);
+    assertEquals(NSEC3Record.Digest.SHA1, nsec3Record.getHashAlgorithm());
+    assertEquals(NSEC3Record.Flags.OPT_OUT, nsec3Record.getFlags());
+    assertNotNull(nsec3Record.getSalt());
+    nsec3Record = new NSEC3Record();
+    nsec3Record.rdataFromString(
         new Tokenizer(
             "1 1 10 - PF2TNEL79K4HTCBINCDBE9FPBU5I04KD A NS SOA MX AAAA RRSIG DNSKEY NSEC3PARAM TYPE65534"),
         null);
-    assertNull(record.getSalt());
+    assertNull(nsec3Record.getSalt());
   }
 }
