@@ -12,9 +12,9 @@ class NSECRecordTest {
   @Test
   void rdataFromString() throws IOException {
     Tokenizer t = new Tokenizer("host.example.com. A MX RRSIG NSEC TYPE1234");
-    NSECRecord record = new NSECRecord();
-    record.rdataFromString(t, null);
-    assertEquals(Name.fromConstantString("host.example.com."), record.getNext());
-    assertFalse(record.hasType(-1));
+    NSECRecord nsecRecord = new NSECRecord();
+    nsecRecord.rdataFromString(t, null);
+    assertEquals(Name.fromConstantString("host.example.com."), nsecRecord.getNext());
+    assertFalse(nsecRecord.hasType(-1));
   }
 }
