@@ -12,9 +12,9 @@ class NXTRecordTest {
   @Test
   void rdataFromString() throws IOException {
     Tokenizer t = new Tokenizer("medium.foo.tld. A MX SIG NXT");
-    NXTRecord record = new NXTRecord();
-    record.rdataFromString(t, null);
-    assertEquals(Name.fromConstantString("medium.foo.tld."), record.getNext());
-    assertNotNull(record.getBitmap());
+    NXTRecord nxtRecord = new NXTRecord();
+    nxtRecord.rdataFromString(t, null);
+    assertEquals(Name.fromConstantString("medium.foo.tld."), nxtRecord.getNext());
+    assertNotNull(nxtRecord.getBitmap());
   }
 }
