@@ -11,10 +11,10 @@ class PXRecordTest {
   @Test
   void rdataFromString() throws IOException {
     Tokenizer t = new Tokenizer("10   net2.it.  PRMD-net2.ADMD-p400.C-it.");
-    PXRecord record = new PXRecord();
-    record.rdataFromString(t, null);
-    assertEquals(10, record.getPreference());
-    assertEquals(Name.fromConstantString("net2.it."), record.getMap822());
-    assertEquals(Name.fromConstantString("PRMD-net2.ADMD-p400.C-it."), record.getMapX400());
+    PXRecord pxRecord = new PXRecord();
+    pxRecord.rdataFromString(t, null);
+    assertEquals(10, pxRecord.getPreference());
+    assertEquals(Name.fromConstantString("net2.it."), pxRecord.getMap822());
+    assertEquals(Name.fromConstantString("PRMD-net2.ADMD-p400.C-it."), pxRecord.getMapX400());
   }
 }
