@@ -1,6 +1,7 @@
 // SPDX-License-Identifier: BSD-3-Clause
 package org.xbill.DNS;
 
+import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
@@ -63,25 +64,30 @@ class TSIGTest {
   }
 
   /**
-   * Check all of the string algorithm names defined in the javadoc. Confirm that java names also
-   * allowed, even though undocumented. THis is to conserve backwards compatibility.
+   * Check all the string algorithm names defined in the javadoc. Confirm that java names also
+   * allowed, even though undocumented. This is to conserve backwards compatibility.
    */
   @ParameterizedTest
-  @ValueSource(
-      strings = {
-        "hmac-md5",
-        "hmac-md5.sig-alg.reg.int.",
-        "hmac-sha1",
-        "hmac-sha224",
-        "hmac-sha256",
-        "hmac-sha256.",
-        "hmac-sha384",
-        "hmac-sha512",
-        // Java names
-        "HmacMD5",
-        "HmacSHA256"
-      })
-  void queryStringAlg(String alg) throws IOException {
+  @CsvSource({
+    "hmac-md5,16",
+    "hmac-md5.sig-alg.reg.int.,16",
+    "hmac-sha1,20",
+    "hmac-sha224,28",
+    "hmac-sha256,32",
+    "hmac-sha256.,32",
+    "hmac-sha256-128,16",
+    "hmac-sha384,48",
+    "hmac-sha384-192,24",
+    "hmac-sha512,64",
+    "hmac-sha512-256,32",
+    // Java names
+    "HmacMD5,16",
+    "HmacSHA1,20",
+    "HmacSHA256,32",
+    "HmacSHA256/128,16",
+    "hmacsha256/128,16",
+  })
+  void queryStringAlg(String alg, int signatureLengthBytes) throws IOException {
     TSIG key = new TSIG(alg, "example.", "12345678");
 
     Record rec = Record.newRecord(Name.fromString("www.example."), Type.A, DClass.IN);
@@ -95,6 +101,7 @@ class TSIGTest {
     assertEquals(Rcode.NOERROR, result);
     assertTrue(parsed.isSigned());
     assertTrue(parsed.isVerified());
+    assertThat(parsed.getTSIG().getSignature()).hasSize(signatureLengthBytes);
   }
 
   /** Confirm error thrown with illegal algorithm name. */
@@ -450,6 +457,23 @@ class TSIGTest {
     }
   }
 
+  @Test
+  void testLargeMessageIsNotLargerThanMax() {
+    Update update = new Update(Name.fromConstantString("zone.example.com."));
+    for (int i = 0; i < 3000; i++) {
+      TXTRecord r =
+          new TXTRecord(
+              Name.fromConstantString("name-" + i + ".zone.example.com."), DClass.IN, 900, "a");
+      update.absent(r.name, r.type);
+      update.add(r);
+    }
+
+    TSIG tsigKey = new TSIG(TSIG.HMAC_SHA384, "zone.example.com.", "c2VjcmU=");
+    update.setTSIG(tsigKey);
+    byte[] wireData = update.toWire(Message.MAXLENGTH);
+    assertThat(wireData).hasSizeLessThan(Message.MAXLENGTH);
+  }
+
   @Test
   void testAxfrLastNotSignedError() throws Exception {
     Name name = Name.fromConstantString("example.com.");
