@@ -13,12 +13,12 @@ class WKSRecordTest {
   @Test
   void rdataFromString() throws IOException {
     Tokenizer t = new Tokenizer("127.0.0.1 tcp ftp telnet smtp");
-    WKSRecord record = new WKSRecord();
-    record.rdataFromString(t, null);
-    assertNotNull(record.getAddress());
-    assertEquals(WKSRecord.Protocol.TCP, record.getProtocol());
+    WKSRecord wksRecord = new WKSRecord();
+    wksRecord.rdataFromString(t, null);
+    assertNotNull(wksRecord.getAddress());
+    assertEquals(WKSRecord.Protocol.TCP, wksRecord.getProtocol());
     assertArrayEquals(
         new int[] {WKSRecord.Service.FTP, WKSRecord.Service.TELNET, WKSRecord.Service.SMTP},
-        record.getServices());
+        wksRecord.getServices());
   }
 }
